==> sql-ledger_2.4.7.orig.tar.gz: sql-ledger/sql/Simplified-Chinese_Default-chart.sql <==
-- Default chart of accounts -- sample only
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2190','Ӧ˰','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600','ڸծ','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300','ɷʱ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500','ӯ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000','ӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4300','ѯӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4400','ӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5000','ɱ','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5400','н֧','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5600','ճ֧','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1205','ʱ','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000','ʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800','ʱʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1825','ۼƷڸ - װ諼豸.','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1845','ۼƷڸ - 乤','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000','ծ','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2620','н','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3600','ӯ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2160','Ӧ˾˰','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3590','ӯ - ȥ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3350','ͨɷ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500','ʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5615','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5790','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5700','칫Ʒ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5800','Ȩ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5610','Ʒ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5685','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5660','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5620','','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5680','˰','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5690','Ϣ','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5410','н','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5420','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5430','ݽ֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5440','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5470','Ա','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4030',' / ','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4440','Ϣ','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5100','˷','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5760','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530',' / ','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1540',' / г','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4040',' / г','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5030','ɱ / ','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010','ɹ','A','','E','AP_amount:IC_cogs:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5040','ɱ / г','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1065','ý','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1820','칫װ諼豸','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5785','÷Ѽ','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2680','ɶ','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5795','ע','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5780','ŷ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5781','·߷','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5765','ά޹','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2311','ط˰','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice:CT_tax');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4430','','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1520',' / Ӳ','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5020','ɱ / Ӳ','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2100','Ӧʿ','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1840','乤','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4330','ʽ','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020',' / Ӳ','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4320','ѯ','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200','Ӧʿ','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1061','֧Ʊͷ','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2310','Ʒ˰','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice:CT_tax');
--
-- exchange rate
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4450','Foreign Exchange Gain','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5810','Foreign Exchange Loss','A','','E','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '2311'),0.08);
--
update defaults set inventory_accno_id = (select id from chart where accno = '1520'), income_accno_id = (select id from chart where accno = '4020'), expense_accno_id = (select id from chart where accno = '5010'), fxgain_accno_id = (select id from chart where accno = '4450'), fxloss_accno_id = (select id from chart where accno = '5810'), curr = 'CAD', weightunit = 'kg';
--

==> sql-ledger_2.6.22.orig.tar.gz: sql-ledger/sql/Simplified-Chinese_Default-chart.sql <==
-- Default chart of accounts -- sample only
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2190','Ӧ˰','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600','ڸծ','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300','ɷʱ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500','ӯ','H','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000','ӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4300','ѯӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4400','ӯ','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5000','ɱ','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5400','н֧','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5600','ճ֧','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1205','ʱ','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000','ʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800','ʱʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link,contra) values ('1825','ۼƷڸ - װ諼豸.','A','','A','','1');
insert into chart (accno,description,charttype,gifi_accno,category,link,contra) values ('1845','ۼƷڸ - 乤','A','','A','','1');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000','ծ','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2620','н','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3600','ӯ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2160','Ӧ˾˰','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3590','ӯ - ȥ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3350','ͨɷ','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500','ʲ','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5615','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5790','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5700','칫Ʒ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5800','Ȩ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5610','Ʒ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5685','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5660','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5620','','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5680','˰','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5690','Ϣ','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5410','н','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5420','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5430','ݽ֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5440','֧','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5470','Ա','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4030',' / ','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4440','Ϣ','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5100','˷','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5760','','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530',' / ','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1540',' / г','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4040',' / г','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5030','ɱ / ','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010','ɹ','A','','E','AP_amount:IC_cogs:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5040','ɱ / г','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1065','ý','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1820','칫װ諼豸','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5785','÷Ѽ','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2680','ɶ','A','','L','AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5795','ע','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5780','ŷ','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5781','·߷','A','','E','AP_amount:IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5765','ά޹','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2311','ط˰','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4430','','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1520',' / Ӳ','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5020','ɱ / Ӳ','A','','E','AP_amount:IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2100','Ӧʿ','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1840','乤','A','','A','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4330','ʽ','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020',' / Ӳ','A','','I','AR_amount:IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4320','ѯ','A','','I','AR_amount:IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200','Ӧʿ','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1061','֧Ʊͷ','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2310','Ʒ˰','A','','L','AR_tax:AP_tax:IC_taxpart:IC_taxservice');
--
-- exchange rate
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4450','Foreign Exchange Gain','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5810','Foreign Exchange Loss','A','','E','');
--
insert into tax (chart_id,rate) values ((select id from chart where accno = '2310'),0.07);
insert into tax (chart_id,rate) values ((select id from chart where accno = '2311'),0.08);
--
update defaults set inventory_accno_id = (select id from chart where accno = '1520'), income_accno_id = (select id from chart where accno = '4020'), expense_accno_id = (select id from chart where accno = '5010'), fxgain_accno_id = (select id from chart where accno = '4450'), fxloss_accno_id = (select id from chart where accno = '5810'), curr = 'CAD', weightunit = 'kg';
--
